# Maesters of NWP(numercial weather prediction)

- A repository focus on how to fecth open-source numerical weather prediction product. 
  - Deutscher Wetterdientst
  - Environment and Climate Change Canada
  - Meteo France
  - ...